@@ -30,18 +30,20 @@ my $lastrow = 0;
 
 open(USER, $file) || die "Cannot open $file for read\n";
 
+my $put_default = 0;
+
 my $sth;
+
 my $sql = '';
 my ($username, $buffer);
 my $lineno = 0;
 while (<USER>) {
   $lineno++;
   chop();
-  chop();
 
   next if /^#/;
 
-  if (/^\t/) {
+  if (/^\s/) {
      $lastrow = 0;
      $_ = substr($_, 1, length($_));
      if (substr($_, length($_) -1, 1) eq ',') {
@@ -52,17 +54,31 @@ while (<USER>) {
      $avreply[0] =~ s/\s+$//;
      $avreply[1] =~ s/^\s+//;
      $avreply[1] =~ s/\s+$//;
+     $avreply[1] =~ s/,$//;
       if (substr($avreply[1], 0, 1) eq '"') {
         chop($avreply[1]);
         $avreply[1] = substr($avreply[1], 1, length($avreply[1]));
       }
+      if ($put_default)
+	{
 
+       	$sth = $dbh->do("INSERT INTO usergroup VALUES \(\'\',\'$username\',\'DEFAULT\'\)");
+	$sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'Auth-Type\', \'System\'\)");
+
+	$put_default = 0;
+
+	}
      $sth = $dbh->do("INSERT INTO radreply VALUES \(\'\',\'$username\',\'$avreply[0]\',\'$avreply[1]\'\)");
 
   } else {
-     next if $_ eq '';
+
+
+      next if $_ eq '';
      $lastrow = 1 if $_ eq '';
-     ($username, $buffer) = split(/\t/);
+     ($username, $buffer) = split(/\t|\s/,$_,2);
+
+     $put_default = 1;
+
 
      my @check = split(/\,/, $buffer);
      foreach (@check) {
@@ -71,16 +87,19 @@ while (<USER>) {
        $avpair[0] =~ s/\s+$//;
        $avpair[1] =~ s/^\s+//;
        $avpair[1] =~ s/\s+$//;
+       $avpair[1] =~ s/,$//;
        if (substr($avpair[1], 0, 1) eq '"') {
 	 # Remove quotes
          chop($avpair[1]);
          $avpair[1] = substr($avpair[1], 1, length($avpair[1]));
        }
+
        $sth = $dbh->do("INSERT INTO radcheck VALUES \(\'\',\'$username\',\'$avpair[0]\',\'$avpair[1]\'\)");
      }
 
   }
 
+
 }
 
 $dbh->disconnect;
