@@ -626,8 +626,8 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 			string[AUTH_PASS_LEN] = '\0';
 			strcpy(userpass, string);
 		}
-		sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &realm_check, authreq->realm, PW_VP_REALMDATA);
-		sql_getvpdata(socket, sql->config->mysql_groupreply_table, &user_reply, authreq->realm, PW_VP_REALMDATA);
+		sql_getvpdata(socket, sql->config->sql_groupcheck_table, &realm_check, authreq->realm, PW_VP_REALMDATA);
+		sql_getvpdata(socket, sql->config->sql_groupreply_table, &user_reply, authreq->realm, PW_VP_REALMDATA);
 
 		if (authreq->server_code == PW_AUTHENTICATION_ACK) {
 			result = 0;
@@ -868,6 +868,16 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 			return -1;
 		}
 
+		if (paircmp(authreq->request, user_check) != 0) {
+			log(L_AUTH, "Check list does not match request list [%s] (%s)", namepair->strvalue, auth_name(authreq, 1));
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, NULL, NULL, activefd);
+			pairfree(user_check);
+			pairfree(user_reply);
+			authfree(authreq);
+			return -1;
+		}
+			
+
 		/*
 		 *	Validate the user
 		 */
@@ -875,6 +885,9 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 			if ((result = check_expiration(user_check, umsg, &user_msg))<0) {
 					rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd); 
 					log(L_AUTH, "Account Expired: [%s] (%s)", namepair->strvalue, auth_name(authreq, 1));
+					pairfree(user_check);
+					pairfree(user_reply);
+					authfree(authreq);
 					return -1;
 			}
 
@@ -887,8 +900,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 				return -1;
 			}
 			if (result == -2) {
-				if ((reply_item = pairfind(user_reply,
-				     PW_REPLY_MESSAGE)) != NULL)
+				if ((reply_item = pairfind(user_reply, PW_REPLY_MESSAGE)) != NULL)
 					user_msg = reply_item->strvalue;
 			}
 		} while(0);
@@ -905,49 +917,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 	}
 
 
-	/* FIXME: Shouldn't this be a paircmp() somewhere to check all nas items? */
-	if (result >=0 && (check_item = pairfind(user_check, PW_NAS_PORT_TYPE)) != NULL) {
-
-		VALUE_PAIR *req;
-
-		if ((req = pairfind(authreq->request, PW_NAS_PORT_TYPE)) != NULL) {
-
-			if (req->lvalue != check_item->lvalue) {
-
-				DICT_ATTR *attr;
-				char *ptype;
-
-				attr = dict_attrget(PW_NAS_PORT_TYPE);
-				ptype = dict_valgetname(req->lvalue, attr->name);
-				sprintf(umsg, "\r\nYou are not authorized for %s\r\n\n", ptype);
-				user_msg = umsg;
-				result = -1;
-				rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
-				log(L_ERR, "Unauthorized port attempt: [%s] (%s) type %s", namepair->strvalue, auth_name(authreq, 1), ptype);
-			}
-			
-		}
-	}
-
-	/*       Check if the user is calling from the specified calling station id */
-	if (result >=0 && (check_item = pairfind(user_check, PW_CALLING_STATION_ID)) != NULL) {
-
-		VALUE_PAIR *req;
-
-		if ((req = pairfind(authreq->request, PW_CALLING_STATION_ID)) !=NULL) {
-
-			if (strcmp(req->strvalue,check_item->strvalue) != 0) {
-
-				sprintf(umsg, "\r\nYou cant login from number %s\r\n\n", req->strvalue);
-				user_msg = umsg;
-				result = -1;
-				rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
-				log(L_ERR, "Unauthorized login attempt: [%s] (%s) (Attempted call from: %s)", namepair->strvalue, auth_name(authreq, 1), check_item->strvalue);
-			}
-		}
-	}
-  
-
 	if (result >=0 && (check_item = pairfind(user_check, PW_TOTAL_TIME_LIMIT)) != NULL) {
 
 		SQL_ROW		row;
@@ -1087,6 +1056,23 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 	}
 
 
+	if (result >= 0 && (check_item = pairfind(user_check, PW_ACTIVATION)) != NULL) {
+
+		time_t		now;
+		struct tm	*actdate;
+
+		now = time(0);
+
+		if (now < check_item->lvalue) {
+			actdate = localtime(&check_item->lvalue);
+			sprintf(umsg, "\r\nYour account is not yet activated\r\n\n");
+			user_msg = umsg;
+			result = -1;
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+			log(L_ERR, "Account not activated until %d-%d-%d: [%s] (%s)", actdate->tm_year+1900, actdate->tm_mon+1, actdate->tm_mday, namepair->strvalue, auth_name(authreq, 1));
+		}
+	}
+
 	if (result >= 0 &&
 	   (check_item = pairfind(user_check, PW_SIMULTANEOUS_USE)) != NULL) {
 #if 0 /* DEBUG */
@@ -1275,12 +1261,11 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 
 	rad_send_reply(PW_AUTHENTICATION_ACK, authreq, user_reply, user_msg, activefd);
 	if (log_auth) {
-#if 1 /* Hide the password for `miquels' :) */
-		if (strcmp(namepair->strvalue, "miquels") == 0)
-			strcpy(userpass, "guess");
-#endif
-		log(L_AUTH, "Login OK: [%s%s%s] (%s) socket %d", namepair->strvalue, log_auth_pass ? "/" : "",
-			log_auth_pass ? userpass : "", auth_name(authreq, 0), socket->id);
+
+		UINT4	curtime = (UINT4)time(NULL);
+
+		log(L_AUTH, "Login OK: [%s%s%s] (%s) socket %d (%d sec)", namepair->strvalue, log_auth_pass ? "/" : "",
+			log_auth_pass ? userpass : "", auth_name(authreq, 0), socket->id, curtime - authreq->timestamp);
 	}
 	if (exec_program && !exec_wait) {
 		/*
