@@ -399,8 +399,7 @@ int presufcmp(VALUE_PAIR *check, char *name, char *rest, int restlen)
  *	Compare two pair lists except for the password information.
  *	Return 0 on match.
  */
-static int paircmp(VALUE_PAIR *request, VALUE_PAIR *check)
-{
+int paircmp(VALUE_PAIR *request, VALUE_PAIR *check) {
 	VALUE_PAIR *check_item = check;
 	VALUE_PAIR *auth_item;
 	int result = 0;
@@ -422,6 +421,11 @@ static int paircmp(VALUE_PAIR *request, VALUE_PAIR *check)
                         case PAM_AUTH_ATTR:
 #endif
 			case PW_SIMULTANEOUS_USE:
+			case PW_MAX_HOURS:
+			case PW_MONTHLY_TIME_LIMIT:
+			case PW_TOTAL_TIME_LIMIT:
+			case PW_ACTIVATION:
+			case PW_RADIUS_OPERATOR:
 			case PW_STRIP_USERNAME:
 				check_item = check_item->next;
 				continue;
@@ -1058,17 +1062,22 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 #endif /* NT_DOMAIN_HACK */
 
 
-	if ((found = sql_getvpdata(socket, sql->config->mysql_authcheck_table, &check_tmp, name, PW_VP_USERDATA)) > 0) {
-		sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &check_tmp, name, PW_VP_GROUPDATA);
-		sql_getvpdata(socket, sql->config->mysql_authreply_table, &reply_tmp, name, PW_VP_USERDATA);
-		sql_getvpdata(socket, sql->config->mysql_groupreply_table, &reply_tmp, name, PW_VP_GROUPDATA);
+	if ((found = sql_getvpdata(socket, sql->config->sql_authcheck_table, &check_tmp, name, PW_VP_USERDATA)) > 0) {
+		sql_getvpdata(socket, sql->config->sql_groupcheck_table, &check_tmp, name, PW_VP_GROUPDATA);
+		sql_getvpdata(socket, sql->config->sql_authreply_table, &reply_tmp, name, PW_VP_USERDATA);
+		sql_getvpdata(socket, sql->config->sql_groupreply_table, &reply_tmp, name, PW_VP_GROUPDATA);
 	} else {
 
 		int gcheck, greply;
-		gcheck = sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &check_tmp, "DEFAULT", PW_VP_GROUPDATA);
-		greply = sql_getvpdata(socket, sql->config->mysql_groupreply_table, &reply_tmp, "DEFAULT", PW_VP_GROUPDATA);
-		if (gcheck == 0 || greply == 0)
-			return -1;
+		gcheck = sql_getvpdata(socket, sql->config->sql_groupcheck_table, &check_tmp, "DEFAULT", PW_VP_GROUPDATA);
+		greply = sql_getvpdata(socket, sql->config->sql_groupreply_table, &reply_tmp, "DEFAULT", PW_VP_GROUPDATA);
+		if (gcheck && greply)
+			found = 1;
+	}
+
+	if (!found) {
+		DEBUG2("User %s not found and DEFAULT not found", name);
+		return -1;
 	}
 
 	pairmove(reply_pairs, &reply_tmp);
