@@ -47,24 +47,24 @@ int sql_init(int reload) {
 		log(L_ERR|L_CONS, "no memory");
 		exit(1);
 	}
-	strcpy(sql->config->mysql_server,"localhost");
-	strcpy(sql->config->mysql_login,"");
-	strcpy(sql->config->mysql_password,"");
-	strcpy(sql->config->mysql_db,"radius");
-	strcpy(sql->config->mysql_authcheck_table,"radcheck");
-	strcpy(sql->config->mysql_authreply_table,"radreply");
-	strcpy(sql->config->mysql_groupcheck_table,"radgroupcheck");
-	strcpy(sql->config->mysql_groupreply_table,"radgroupreply");
-	strcpy(sql->config->mysql_usergroup_table,"usergroup");
-	strcpy(sql->config->mysql_realmgroup_table,"realmgroup");
-	strcpy(sql->config->mysql_acct_table,"radacct");
+	strcpy(sql->config->sql_server,"localhost");
+	strcpy(sql->config->sql_login,"");
+	strcpy(sql->config->sql_password,"");
+	strcpy(sql->config->sql_db,"radius");
+	strcpy(sql->config->sql_authcheck_table,"radcheck");
+	strcpy(sql->config->sql_authreply_table,"radreply");
+	strcpy(sql->config->sql_groupcheck_table,"radgroupcheck");
+	strcpy(sql->config->sql_groupreply_table,"radgroupreply");
+	strcpy(sql->config->sql_usergroup_table,"usergroup");
+	strcpy(sql->config->sql_realmgroup_table,"realmgroup");
+	strcpy(sql->config->sql_acct_table,"radacct");
 	sql->config->sqltrace = 0;
 	sql->config->sensitiveusername = 1;
 	sql->config->deletestalesessions = 0;
 
-	strcpy(sql->config->mysql_nas_table,"nas");
-	strcpy(sql->config->mysql_realm_table, "realms");
-	strcpy(sql->config->mysql_dict_table,"dictionary");
+	strcpy(sql->config->sql_nas_table,"nas");
+	strcpy(sql->config->sql_realm_table, "realms");
+	strcpy(sql->config->sql_dict_table,"dictionary");
 	sql->config->max_sql_socks = MAX_SQL_SOCKS;
 
         sprintf(sqlfile, "%s/%s", radius_dir, MYSQLCONFIG);
@@ -87,7 +87,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strcpy(sql->config->mysql_server,namestr);
+                         strcpy(sql->config->sql_server,namestr);
                        }
                }
                 if(strncasecmp(buffer, "login", 5) == 0) {
@@ -95,7 +95,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strcpy(sql->config->mysql_login,namestr);
+                         strcpy(sql->config->sql_login,namestr);
                        }
                }
                 if(strncasecmp(buffer, "password", 8) == 0) {
@@ -103,7 +103,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strcpy(sql->config->mysql_password,namestr);
+                         strcpy(sql->config->sql_password,namestr);
                        }
                }
                 if(strncasecmp(buffer, "radius_db", 9) == 0) {
@@ -111,7 +111,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strcpy(sql->config->mysql_db,namestr);
+                         strcpy(sql->config->sql_db,namestr);
                        }
                }
                 if(strncasecmp(buffer, "authcheck_table", 15) == 0) {
@@ -119,7 +119,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_authcheck_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_authcheck_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "authreply_table", 15) == 0) {
@@ -127,7 +127,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_authreply_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_authreply_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "groupcheck_table", 16) == 0) {
@@ -135,7 +135,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_groupcheck_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_groupcheck_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "groupreply_table", 16) == 0) {
@@ -143,7 +143,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_groupreply_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_groupreply_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "usergroup_table", 15) == 0) {
@@ -151,7 +151,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_usergroup_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_usergroup_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "realmgroup_table", 16) == 0) {
@@ -159,7 +159,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_realmgroup_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_realmgroup_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "acct_table", 10) == 0) {
@@ -167,7 +167,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_acct_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_acct_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "nas_table", 9) == 0) {
@@ -175,7 +175,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_nas_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_nas_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "realm_table", 9) == 0) {
@@ -183,7 +183,7 @@ int sql_init(int reload) {
                        if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                       } else {
-                         strncpy(sql->config->mysql_realm_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_realm_table,namestr, MAX_TABLE_LEN);
                       }
                }
                 if(strncasecmp(buffer, "dict_table", 9) == 0) {
@@ -191,7 +191,7 @@ int sql_init(int reload) {
                         if(sscanf(buffer, "%s%s", dummystr, namestr) != 2) {
                                log(L_ERR,"invalid attribute on line %d of configuration file %s", line_no,sqlfile);
                        } else {
-                         strncpy(sql->config->mysql_dict_table,namestr, MAX_TABLE_LEN);
+                         strncpy(sql->config->sql_dict_table,namestr, MAX_TABLE_LEN);
                        }
                }
                 if(strncasecmp(buffer, "sqltrace", 8) == 0) {
@@ -234,7 +234,7 @@ int sql_init(int reload) {
        }
        fclose(sqlfd);
        
-       log(L_INFO,"SQL: Attempting to connect to %s@%s:%s", sql->config->mysql_login, sql->config->mysql_server, sql->config->mysql_db);
+       log(L_INFO,"SQL: Attempting to connect to %s@%s:%s", sql->config->sql_login, sql->config->sql_server, sql->config->sql_db);
 
        sql_init_socket(reload);
            
@@ -242,6 +242,54 @@ int sql_init(int reload) {
 }
 
 
+/*************************************************************************
+ *
+ *	Function: sql_init_socket
+ *
+ *	Purpose: Connect to the sql server
+ *
+ *************************************************************************/
+int sql_init_socket(int reload) {
+
+	int i;
+
+	/* Clear up old connections if reload */
+	if (reload)
+	        for (i = 0; i < sql->config->max_sql_socks; i++)
+			if (!sql_close_socket(sql->socks[i]))
+				log(L_CONS|L_ERR, "Could not release socket %d", i);
+	
+
+        /* Initalize our connection pool */
+        for (i = 0; i < sql->config->max_sql_socks; i++) {
+	 	if ((sql->socks[i] = sql_create_socket()) == NULL) {
+	   		log(L_CONS|L_ERR, "SQL: Failed to connect socket %d", i);
+		} else {
+	   		sql->socks[i]->id = i;
+           		sql->socks[i]->in_use = 0;
+	   		DEBUG2("SQL: Connected socket %d", i);
+		}
+	}
+           
+       return 1;
+}
+
+
+/*************************************************************************
+ *
+ *	Function: sql_close_socket
+ *
+ *	Purpose: Close and free a sql socket
+ *
+ *************************************************************************/
+int sql_close_socket(SQLSOCK *socket) {
+	DEBUG2("SQL: Closing socket %d", socket->id);
+	sql_close(socket);
+	free(socket);
+	return 1;
+}
+ 
+
 /*************************************************************************
  *
  *	Function: sql_get_socket
@@ -259,6 +307,7 @@ SQLSOCK *sql_get_socket(void) {
 			i = 0;
 		if (sql->socks[i]->in_use == 0) {
 			sql->socks[i]->in_use = 1;
+			gettimeofday(&(sql->socks[i]->tv), NULL);
 			DEBUG2("SQL: Reserved socket %d", i);
 			return sql->socks[i];
 		}
@@ -275,6 +324,19 @@ SQLSOCK *sql_get_socket(void) {
  *************************************************************************/
 int sql_release_socket(SQLSOCK *socket) {
 
+	struct timeval	tv;
+	double		start, end;
+	char		buff[24];
+
+	gettimeofday(&tv, NULL);
+	sprintf(buff, "%ld.%2ld", tv.tv_sec, tv.tv_usec);
+	end = strtod(buff, NULL);
+	sprintf(buff, "%ld %2.0ld", socket->tv.tv_sec, socket->tv.tv_usec);
+	start = strtod(buff, NULL);
+	DEBUG2("SQL: Socket %d used for %.2f seconds", socket->id, end - start);
+
+	socket->tv.tv_sec = tv.tv_sec;
+	socket->tv.tv_usec = tv.tv_usec;
 	sql->socks[socket->id]->in_use = 0;
 	DEBUG2("SQL: Released socket %d", socket->id);
 	return 1;
@@ -331,7 +393,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
          /* The Terminal server informed us that it was rebooted
          * STOP all records from this NAS */
 
-         sprintf(querystr, "UPDATE %s SET AcctStopTime='%s', AcctSessionTime=unix_timestamp('%s') - unix_timestamp(AcctStartTime), AcctTerminateCause='%s', AcctStopDelay = %ld WHERE AcctSessionTime=0 AND AcctStopTime=0 AND NASIPAddress= '%s' AND AcctStartTime <= '%s'", sql->config->mysql_acct_table, sqlrecord->AcctTimeStamp, sqlrecord->AcctTimeStamp, sqlrecord->AcctTerminateCause, sqlrecord->AcctDelayTime, sqlrecord->NASIPAddress, sqlrecord->AcctTimeStamp);
+         sprintf(querystr, "UPDATE %s SET AcctStopTime='%s', AcctSessionTime=unix_timestamp('%s') - unix_timestamp(AcctStartTime), AcctTerminateCause='%s', AcctStopDelay = %ld WHERE AcctSessionTime=0 AND AcctStopTime=0 AND NASIPAddress= '%s' AND AcctStartTime <= '%s'", sql->config->sql_acct_table, sqlrecord->AcctTimeStamp, sqlrecord->AcctTimeStamp, sqlrecord->AcctTerminateCause, sqlrecord->AcctDelayTime, sqlrecord->NASIPAddress, sqlrecord->AcctTimeStamp);
 
        	 if (sql_query(socket, querystr) < 0)
 	      log(L_ERR, "Acct: Couldn't update SQL accounting after NAS reboot - %s", sql_error(socket));
@@ -346,7 +408,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
       } 
 
 	if (sqlrecord->AcctStatusTypeId == PW_STATUS_ALIVE) {
-		sprintf(querystr, "UPDATE %s SET FramedIPAddress = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress= '%s'", sql->config->mysql_acct_table, sqlrecord->FramedIPAddress, sqlrecord->AcctSessionId, sqlrecord->UserName, sqlrecord->NASIPAddress);
+		sprintf(querystr, "UPDATE %s SET FramedIPAddress = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress= '%s'", sql->config->sql_acct_table, sqlrecord->FramedIPAddress, sqlrecord->AcctSessionId, sqlrecord->UserName, sqlrecord->NASIPAddress);
 		if (sql_query(socket, querystr) < 0)
 			log(L_ERR, "Acct: Couldn't update SQL accounting for ALIVE packet - %s", sql_error(socket));
 		sql_finish_query(socket);
@@ -364,7 +426,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
              
              /* Set start time on record with only a stop record */
  	     snprintf(querystr, 2048, "UPDATE %s SET AcctStartTime = '%s', AcctStartDelay = %ld WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
-	     sql->config->mysql_acct_table,
+	     sql->config->sql_acct_table,
              sqlrecord->AcctTimeStamp,
 	     sqlrecord->AcctDelayTime,
              sqlrecord->AcctSessionId,
@@ -380,7 +442,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
 
                 /* Insert new record with blank stop time until stop record is got */
                 snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', '%s', 0, 0, '%s', '%s', 0, 0, '%s', '%s', '', '%s', '%s', '%s', %ld, 0)",
-                sql->config->mysql_acct_table,
+                sql->config->sql_acct_table,
                 sqlrecord->AcctSessionId,
                 sqlrecord->UserName,
                 sqlrecord->Realm,
@@ -406,14 +468,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
            /* Got stop record */
            } else {
 
-		/* If stop but zero session length drop it as in invalid packet */
-		/* This is to fix CISCO's aaa from filling our table with bogus crap */
-		if (sqlrecord->AcctSessionTime <= 0) {
-			log(L_ERR, "Acct: Invalid STOP record. [%s] STOP record but zero session length? (nas %s)", sqlrecord->UserName, sqlrecord->NASIPAddress);
-			return 0;
-		}
-
-             sprintf(querystr, "SELECT RadAcctId FROM %s WHERE AcctSessionId='%s' AND NASIPAddress='%s' AND UserName='%s'", sql->config->mysql_acct_table, sqlrecord->AcctSessionId, sqlrecord->NASIPAddress, sqlrecord->UserName);
+             sprintf(querystr, "SELECT RadAcctId FROM %s WHERE AcctSessionId='%s' AND NASIPAddress='%s' AND UserName='%s'", sql->config->sql_acct_table, sqlrecord->AcctSessionId, sqlrecord->NASIPAddress, sqlrecord->UserName);
               sql_select_query(socket, querystr);
               num = sql_num_rows(socket);
 	      sql_finish_select_query(socket);
@@ -422,7 +477,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
 
                 /* Set stop time on matching record with start time */
  	        snprintf(querystr, 2048, "UPDATE %s SET AcctStopTime = '%s', AcctSessionTime = '%lu', AcctInputOctets = '%lu', AcctOutputOctets = '%lu', AcctTerminateCause = '%s', AcctStopDelay = %ld WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
-	        sql->config->mysql_acct_table,
+	        sql->config->sql_acct_table,
                 sqlrecord->AcctTimeStamp,
                 sqlrecord->AcctSessionTime,
                 sqlrecord->AcctInputOctets,
@@ -441,10 +496,18 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
 
              } else if (num == 0) {
 
+#ifdef CISCO_ACCOUNTING_HACK
+		/* If stop but zero session length AND no previous session found, drop it as in invalid packet */
+		/* This is to fix CISCO's aaa from filling our table with bogus crap */
+		if (sqlrecord->AcctSessionTime <= 0) {
+			log(L_ERR, "Acct: Invalid STOP record. [%s] STOP record but zero session length? (nas %s)", sqlrecord->UserName, sqlrecord->NASIPAddress);
+			return 0;
+		}
+#endif
             
                 /* Insert record with no start time until matching start record comes */
                 snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', 0, '%s', '%lu', '%s', '%s', '%lu', '%lu', '%s', '%s', '%s', '%s', '%s', '%s', 0, %ld)",
-                sql->config->mysql_acct_table,
+                sql->config->sql_acct_table,
                 sqlrecord->AcctSessionId,
                 sqlrecord->UserName,
                 sqlrecord->Realm,
@@ -491,7 +554,7 @@ int sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord) {
  *	Purpose: Read entries from the database and fill VALUE_PAIR structures
  *
  *************************************************************************/
-int sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row) {
+int sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row, int mode) {
 
 	int x;
 	char		*s;
@@ -511,7 +574,7 @@ int sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row) {
 
 	/* If attribute is already there, skip it because we checked usercheck first 
 	   and we want user settings to over ride group settings */
-	if ((check = pairfind(*first_pair, attr->value)) != NULL)
+	if ((check = pairfind(*first_pair, attr->value)) != NULL && mode == PW_VP_GROUPDATA)
 		return 0;
 
 	if((pair = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR))) == (VALUE_PAIR *)NULL) {
@@ -650,20 +713,20 @@ int sql_getvpdata(SQLSOCK *socket, char *table, VALUE_PAIR **vp, char *user, int
 			sprintf(authstr, "STRCMP(Username, '%s') = 0", username);
 		else
 			sprintf(authstr, "UserName = '%s'", username);
-		sprintf(querystr, "SELECT * FROM %s WHERE %s", table, authstr);
+		sprintf(querystr, "SELECT id, UserName, Attribute, Value FROM %s WHERE %s ORDER BY id", table, authstr);
 	} else if (mode == PW_VP_GROUPDATA) {
 		if (sql->config->sensitiveusername) 
-			sprintf(authstr, "STRCMP(%s.Username, '%s') = 0", sql->config->mysql_usergroup_table, username);
+			sprintf(authstr, "STRCMP(%s.Username, '%s') = 0", sql->config->sql_usergroup_table, username);
 		else
-			sprintf(authstr, "%s.UserName = '%s'",sql->config->mysql_usergroup_table, username);
-		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, sql->config->mysql_usergroup_table, authstr, sql->config->mysql_usergroup_table, table, table);
+			sprintf(authstr, "%s.UserName = '%s'",sql->config->sql_usergroup_table, username);
+		sprintf(querystr, "SELECT %s.id, %s.GroupName, %s.Attribute, %s.Value FROM %s, %s WHERE %s AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, table, table, table, sql->config->sql_usergroup_table, authstr, sql->config->sql_usergroup_table, table, table);
 	} else if (mode == PW_VP_REALMDATA)
-		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s.RealmName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, sql->config->mysql_realmgroup_table, sql->config->mysql_realmgroup_table, username, sql->config->mysql_realmgroup_table, table, table);
+		sprintf(querystr, "SELECT %s.id, %s.GroupName, %s.Attribute, %s.Value FROM %s, %s WHERE %s.RealmName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, table, table, table, sql->config->sql_realmgroup_table, sql->config->sql_realmgroup_table, username, sql->config->sql_realmgroup_table, table, table);
 	sql_select_query(socket, querystr);
 	rows = sql_num_rows(socket);
 	while ((row = sql_fetch_row(socket))) {
 
-		if (sql_userparse(vp, row) != 0) {
+		if (sql_userparse(vp, row, mode) != 0) {
 	 		log(L_ERR|L_CONS, "Error getting data from SQL");
 			sql_finish_select_query(socket);
 			return -1;
@@ -793,7 +856,7 @@ int sql_check_multi(SQLSOCK *socket, char *name, VALUE_PAIR *request, int maxsim
 		sprintf(authstr, "STRCMP(UserName, '%s') = 0", name);
 	else
 		sprintf(authstr, "UserName = '%s'", name);
-	sprintf(querystr, "SELECT COUNT(*) FROM %s WHERE %s AND AcctStopTime = 0", sql->config->mysql_acct_table, authstr);
+	sprintf(querystr, "SELECT COUNT(*) FROM %s WHERE %s AND AcctStopTime = 0", sql->config->sql_acct_table, authstr);
 	sql_select_query(socket, querystr);
 	row = sql_fetch_row(socket);
 	count = atoi(row[0]);
@@ -809,32 +872,32 @@ int sql_check_multi(SQLSOCK *socket, char *name, VALUE_PAIR *request, int maxsim
 		ipno = htonl(fra->lvalue);
 
 	count = 0;
-	sprintf(querystr, "SELECT * FROM %s WHERE %s AND AcctStopTime = 0", sql->config->mysql_acct_table, authstr);
+	sprintf(querystr, "SELECT RadAcctId, UserName, NASIPAddress, NASPortId, FramedIPAddress FROM %s WHERE %s AND AcctStopTime = 0", sql->config->sql_acct_table, authstr);
 	sql_select_query(socket, querystr);
 	while ((row = sql_fetch_row(socket))) {
 		int check = sql_check_ts(row);
 		if (check == 1) {
 			count++;
 
-			if (ipno && atoi(row[19]) == ipno)
+			if (ipno && atoi(row[4]) == ipno)
 				mpp = 2;   
 
 		} else if (check == 2)
-			log(L_ERR,"Problem with checkrad [%s] (from nas %s)", name, row[4]);
+			log(L_ERR,"Problem with checkrad [%s] (from nas %s)", name, row[2]);
 		else {
 			/*
 			 *	False record - zap it
 			 */
 
 			if (sql->config->deletestalesessions) {
-				SQLSOCK *socket;
+				SQLSOCK *sock;
 
-   				log(L_ERR,"Deleteing stale session [%s] (from nas %s/%s)", row[2], row[4], row[5]);
-				socket = sql_get_socket();
-				sprintf(querystr, "DELETE FROM %s WHERE RadAcctId = '%s'", sql->config->mysql_acct_table, row[0]);
-				sql_query(socket, querystr);
-				sql_finish_query(socket);
-				sql_close_socket(socket);
+   				log(L_ERR,"Deleteing stale session [%s] (from nas %s/%s)", row[1], row[2], row[3]);
+				sock = sql_create_socket();
+				sprintf(querystr, "DELETE FROM %s WHERE RadAcctId = '%s'", sql->config->sql_acct_table, row[0]);
+				sql_query(sock, querystr);
+				sql_finish_query(sock);
+				sql_close_socket(sock);
 			}
 		}
 	}
@@ -856,7 +919,7 @@ int sql_read_naslist(SQLSOCK *socket) {
         nas_free(naslist);
         naslist = NULL;
 
-	sprintf(querystr, "SELECT * FROM %s", sql->config->mysql_nas_table);
+	sprintf(querystr, "SELECT * FROM %s", sql->config->sql_nas_table);
 	sql_select_query(socket, querystr);
 	while ((row = sql_fetch_row(socket))) {
 		if ((c = malloc(sizeof(NAS))) == NULL) {
@@ -902,7 +965,7 @@ int sql_read_clients(SQLSOCK *socket) {
         clients_free(clients);
         clients = NULL;
 
-	sprintf(querystr, "SELECT * FROM %s", sql->config->mysql_nas_table);
+	sprintf(querystr, "SELECT * FROM %s", sql->config->sql_nas_table);
 	sql_select_query(socket, querystr);
 	while ((row = sql_fetch_row(socket))) {
 		if ((c = malloc(sizeof(CLIENT))) == NULL) {
@@ -955,7 +1018,7 @@ int sql_dict_init(SQLSOCK *socket) {
 
 	dict_free();
 
-	sprintf(querystr, "SELECT * FROM %s", sql->config->mysql_dict_table);
+	sprintf(querystr, "SELECT * FROM %s", sql->config->sql_dict_table);
 	sql_select_query(socket, querystr);
 	while ((row = sql_fetch_row(socket))) {
 		line_no = strtol(row[0], NULL, 0);
@@ -1167,7 +1230,7 @@ int sql_read_realms(SQLSOCK *socket) {
    /* Maybe realm.nas should refer exact to either nas.nasname 
       or nas.shortname. Either way, GROUP BY makes the realmnames 
       unique - CS */
-   sprintf(querystr, "SELECT realmname, nasname, ipaddr, authport, options FROM %s, %s WHERE nas = nasname OR nas = shortname or nas = ipaddr GROUP BY realmname", sql->config->mysql_realm_table, sql->config->mysql_nas_table);
+   sprintf(querystr, "SELECT realmname, nasname, ipaddr, authport, options FROM %s, %s WHERE nas = nasname OR nas = shortname or nas = ipaddr GROUP BY realmname", sql->config->sql_realm_table, sql->config->sql_nas_table);
    
    sql_select_query(socket, querystr);
    
