@@ -61,7 +61,6 @@ int rad_send_reply(int code, AUTH_REQ *authreq, VALUE_PAIR *oreply,
 			 */
 			reply = NULL;
 			pairmove2(&reply, &oreply, PW_REPLY_MESSAGE);
-			pairmove2(&reply, &oreply, PW_PROXY_STATE);
 			break;
 		case PW_ACCESS_CHALLENGE:
 			what = "Challenge";
@@ -77,6 +76,18 @@ int rad_send_reply(int code, AUTH_REQ *authreq, VALUE_PAIR *oreply,
 			break;
 	}
 
+	/* this could be more efficient, but it works... */
+
+	/*	DEBUG("authreq proxy pairs contains:\n");
+
+	fprint_attr_list(stdout,authreq->proxy_pairs); 
+	*/
+
+	pairmove2(&reply, &authreq->proxy_pairs, PW_PROXY_STATE);
+
+	DEBUG2("Proxy pairs added!\n");
+
+
 	/*
 	 *	Build standard header
 	 */
@@ -384,6 +395,7 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 	memcpy(authreq->vector, auth->vector, AUTH_VECTOR_LEN);
 	authreq->data = buffer;
 	authreq->data_len = length;
+	authreq->proxy_pairs = NULL;
 
 	/*
 	 *	Extract attribute-value pairs
@@ -514,6 +526,11 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 		if (vendorlen > 0) vendorlen -= (attrlen + 2);
 	}
 	authreq->request = first_pair;
+
+
+        /* hide the proxy pairs from the rest of the server */
+        pairmove2(&authreq->proxy_pairs, &authreq->request, PW_PROXY_STATE);
+
 	return(authreq);
 }
 
