@@ -55,11 +55,9 @@ typedef struct pw_auth_hdr {
 #define PW_TYPE_IPADDR			2
 #define PW_TYPE_DATE			3
 
-#define	PW_VP_CHECK			1
-#define	PW_VP_REPLY			2
-
 #define PW_VP_USERDATA			1
 #define PW_VP_GROUPDATA			2
+#define PW_VP_REALMDATA			3
 
 #define	PW_AUTHENTICATION_REQUEST	1
 #define	PW_AUTHENTICATION_ACK		2
@@ -121,7 +119,14 @@ typedef struct pw_auth_hdr {
 #define PW_PORT_LIMIT			62
 #define PW_CONNECT_INFO			77
 
-#define PW_HUNTGROUP_NAME		221
+#define PW_RADIUS_OPERATOR		100
+
+#define PW_FALL_THROUGH			500
+#define PW_ADD_PORT_TO_IP_ADDRESS	501
+#define PW_EXEC_PROGRAM			502
+#define PW_EXEC_PROGRAM_WAIT		503
+
+#define PW_HUNTGROUP_NAME		1031
 #define PW_AUTHTYPE			1000
 #define PW_PREFIX			1003
 #define PW_SUFFIX			1004
@@ -132,15 +137,13 @@ typedef struct pw_auth_hdr {
 #define PW_GROUP_NAME			1030
 #define PW_SIMULTANEOUS_USE		1034
 #define PW_STRIP_USERNAME		1035
-#define PW_FALL_THROUGH			1036
-#define PW_ADD_PORT_TO_IP_ADDRESS	1037
-#define PW_EXEC_PROGRAM			1038
-#define PW_EXEC_PROGRAM_WAIT		1039
 #define PW_HINT				1040
 #define PAM_AUTH_ATTR			1041
 #define PW_LOGIN_TIME			1042
-#define PW_RADIUS_OPERATOR		2000
 #define PW_MAX_HOURS			2001
+#define PW_MONTHLY_TIME_LIMIT		2002
+#define PW_TOTAL_TIME_LIMIT		2003
+#define PW_ACTIVATION			2004
 
 /*
  *	INTEGER TRANSLATIONS
