@@ -272,11 +272,6 @@ int main(int argc, char **argv)
 		case 's':	/* Single process mode */
 			spawn_flag = 0;
 			break;
-/* Hopfully fixed by adding sql pool
-		case 'n':
-			fork_auth = 1;
-			break;
-*/
 
 		case 'v':
 			version();
@@ -657,9 +652,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun, SQLSOCK *
 				/*
 				 * This is a duplicate request - just drop it
 				 */
-				log(L_ERR,
-				"Dropping duplicate authentication packet"
-				" from client %s - ID: %d",
+				log(L_ERR, "Dropping duplicate authentication packet from client %s - ID: %d",
 				client_name(authreq->ipaddr), authreq->id);
 				sql_release_socket(socket);
 				pairfree(authreq->request);
