@@ -296,6 +296,7 @@ char		*nas_name2(AUTH_REQ *r);
 char		*auth_name(AUTH_REQ *authreq, int do_cid);
 int		read_naslist_file(char *);
 int		read_config_files(SQLSOCK *socket);
+int		paircmp(VALUE_PAIR *request, VALUE_PAIR *check);
 int		presufcmp(VALUE_PAIR *check, char *name, char *rest, int rl);
 void		pairmove(VALUE_PAIR **to, VALUE_PAIR **from);
 void		pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
@@ -335,10 +336,12 @@ char		*radius_xlate(char *, VALUE_PAIR *req, VALUE_PAIR *reply);
 
 /* mysql.c */
 int		sql_init(int reload);
+int		sql_init_socket(int reload);
+int		sql_close_socket(SQLSOCK *socket);
 SQLSOCK		*sql_get_socket(void);
 int		sql_release_socket(SQLSOCK *socket);
 int		sql_save_acct(SQLSOCK *socket, SQLREC *sqlrecord);
-int		sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row);
+int		sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row, int mode);
 int		sql_read_realms(SQLSOCK *socket);
 int		sql_getvpdata(SQLSOCK *socket, char *table, VALUE_PAIR **vp, char *user, int mode);
 int		sql_check_multi(SQLSOCK *socket, char *name, VALUE_PAIR *request, int maxsimul);
