@@ -37,7 +37,7 @@ char version_sccsid[] =
  *  would like a range of versions allocated for your use.
  */
 
-#define		VERSION		"cistron-1.6.2 19-Jan-2000 +ICRADIUS 0.12"
+#define		VERSION		"ICRADIUS 0.13 built " __DATE__
 
 /*
  *	Display the revision number for this program
@@ -49,12 +49,6 @@ void version(void)
 	fprintf(stderr, "Compilation flags: ");
 
 	/* here are all the conditional feature flags */
-#if defined(DBM)
-	fprintf(stderr," DBM");
-#endif
-#if defined(NDBM)
-	fprintf(stderr," NDBM");
-#endif
 #if defined(NOSHADOW)
 	fprintf(stderr," NOSHADOW");
 #endif
@@ -67,6 +61,9 @@ void version(void)
 #if defined(SPECIALIX_JETSTREAM_HACK)
 	fprintf(stderr," SPECIALIX_JETSTREAM_HACK");
 #endif
+#if defined(CISCO_ACCOUNTING_HACK)
+	fprintf(stderr, " CISCO_ACCOUNTING_HACK");
+#endif
 #if defined(NOCASE)
 	fprintf(stderr," NOCASE");
 #endif
